==> xoonips-3.30.tar.gz: xoonips-3.30/xoonips/class/xmlrpc/xmlrpctransformfile.class.php <==
<?php
// $Revision: 1.1.2.2 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

include_once XOOPS_ROOT_PATH . '/modules/xoonips/class/orm/file.class.php';
//include_once XOOPS_ROOT_PATH . '/modules/xoonips/include/functions.php';
class XooNIpsXmlRpcTransformFile extends XooNIpsXmlRpcTransformElement
{
    function getObject($array) 
    {
        $obj = &new XooNIpsFile();
        //
        // filetype to file_type_id
        $file_type_handler = &xoonips_getormhandler('xoonips', 'file_type');
        $filetypes = &$file_type_handler->getObjects(new Criteria('name', $array['filetype']));
        if (!$filetypes || count($filetypes) != 1) return false;
        //
        //
        $obj->assignVar('file_id', $array['id']);
        $obj->assignVar('file_type_id', $filetypes[0]->getVar('file_type_id'));
        $obj->assignVar('original_file_name', $array['originalname']);
        $obj->assignVar('file_size', intval($array['size']));
        $obj->assignVar('mime_type', $array['mimetype']);
        $obj->assignVar('caption', $array['caption']);
        $obj->assignVar('thumbnail_file', $array['thumbnail']);
        return $obj;
    }
}
?>

==> xoonips-3.32.tar.gz: xoonips-3.32/xoonips/class/xmlrpc/xmlrpctransformfile.class.php <==
<?php
// $Revision: 1.1.2.3 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

include_once XOOPS_ROOT_PATH . '/modules/xoonips/class/orm/file.class.php';
//include_once XOOPS_ROOT_PATH . '/modules/xoonips/include/functions.php';
class XooNIpsXmlRpcTransformFile extends XooNIpsXmlRpcTransformElement
{
    function getObject($array) 
    {
        $obj = &new XooNIpsFile();
        //
        // filetype to file_type_id
        $file_type_handler = &xoonips_getormhandler('xoonips', 'file_type');
        $filetypes = &$file_type_handler->getObjects(new Criteria('name', $array['filetype']));
        if (!$filetypes || count($filetypes) != 1) return false;
        //
        //
        $obj->assignVar('file_id', $array['id']);
        $obj->assignVar('file_type_id', $filetypes[0]->getVar('file_type_id'));
        $obj->assignVar('original_file_name', encodeClient2Server( $array['originalname'] ) );
        $obj->assignVar('file_size', intval($array['size']));
        $obj->assignVar('mime_type', $array['mimetype']);
        $obj->assignVar('caption', encodeClient2Server( $array['caption'] ) );
        $obj->assignVar('thumbnail_file', $array['thumbnail']);
        return $obj;
    }
}
?>
